<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Banner;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cache;

class BannerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $banners = Banner::paginate(10);

        return view('admin.banners.index', compact('banners'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.banners.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        request()->validate([
            'title' => 'required',
            'image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:2048',
        ],
        [
            'title.required' => 'Banner title is required.',
            'image.required' => 'Banner Image is required',
        ]);
        $banner = new Banner;
        $imageName = "";
        if($request->hasFile('image')){
            $imageName = time().'.'.$request->image->extension();
            $request->image->move(public_path('banner_img'), $imageName);
        }

        $is_published = (isset($request->is_published)) ? 1 : 0;

        $banner = Banner::create([
            'title'       => $request->title,
            'link'        => $request->link,
            'image'       => $imageName,
            'is_published'  => $is_published,
        ]);

        flash()->overlay('Banner created successfully.');

        return redirect('/admin/banners');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Banner $banner)
    {
        return view('admin.banners.edit', compact('banner'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Banner $banner)
    {
        request()->validate([
            'title' => 'required',
        ],
        [
            'title.required' => 'Banner title is required.',
        ]);

        $is_published = (isset($request->is_published)) ? 1 : 0;
    
        if($request->hasFile('image')){
            $imageName = time().'.'.$request->image->extension();
            $request->image->move(public_path('banner_img'), $imageName);
            $banner->update([
                'title'       => $request->title,
                'link'        => $request->link,
                'image'       => $imageName,
                'is_published'  => $is_published,
            ]);
        }
        else{
            $banner->update([
                'title'       => $request->title,
                'link'        => $request->link,
                'is_published'  => $is_published,
            ]);
        }

        flash()->overlay('Banner updated successfully.');

        return redirect('/admin/banners');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Banner $banner)
    {
        $banner->delete();
        flash()->overlay('Banner deleted successfully.');

        return redirect('/admin/banners');
    }

    public function publish(Banner $banner)
    {
        $banner->is_published = ! $banner->is_published;
        $banner->save();
        flash()->overlay('Banner status changed successfully.');

        return redirect('/admin/banners');
    }
}
