<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Tag;
use Illuminate\Http\Request;

class TagController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $tags = Tag::paginate(10);

        return view('admin.tags.index', compact('tags'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.tags.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $tag = new Tag;
        $slug = $tag->setSlugAttribute($request->name);
        $is_popular = (isset($request->is_popular)) ? 1 : 0;
        $this->validate($request, ['name' => 'required']);

        Tag::create(['name' => $request->name, 'is_popular' => $is_popular,'slug' => $slug]);
        flash()->overlay('Tag created successfully.');

        return redirect('/admin/tags');
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit(Tag $tag)
    {
        return view('admin.tags.edit', compact('tag'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Tag $tag)
    {
        $is_popular = (isset($request->is_popular)) ? 1 : 0;
        $this->validate($request, ['name' => 'required']);

        $tag->update(['name' => $request->name, 'is_popular' => $is_popular]);
        flash()->overlay('Tag updated successfully.');

        return redirect('/admin/tags');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(Tag $tag)
    {
        $tag->delete();
        flash()->overlay('Tag deleted successfully.');

        return redirect('/admin/tags');
    }
}
