<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\User;
use Illuminate\Http\Request;

class UserController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $users = User::withCount('posts')->paginate(10);

        return view('admin.users.index', compact('users'));
    }
    
    public function edit(User $user)
    {
        return view('admin.users.edit', compact('user'));
    }
	
	public function update(Request $request, User $user)
    {
        request()->validate([
            'name' => 'required',
			'email' => 'required|email|max:255',
            'password' => 'required|min:6',
        ],
        [
            'name.required' => 'User Full name is required.',
			'email.required' => 'User Email is required.',
			'password.required' => 'User Password is required',
        ]);
    
        $user->update([
                'name'       => $request->name,
                'email'        => $request->email,
                'password'  => bcrypt($request->password),
            ]);

        flash()->overlay('User Details updated successfully.');

        return redirect('/admin/users');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy(User $user)
    {
        if (auth()->user() == $user) {
            flash()->overlay("You can't delete yourself.");

            return redirect('/admin/users');
        }

        $user->delete();
        flash()->overlay('User deleted successfully.');

        return redirect('/admin/users');
    }
}
