<?php

namespace App\Http\Controllers;

use App\Models\Post;
use App\Models\Tag;
use App\Models\Category;
use App\Models\Setting;
use App\Models\Banner;
use Illuminate\Http\Request;

class BlogController extends Controller
{
    public function index(Request $request)
    {
        $view_type = ($request->list_type) ?? 'list';
        $posts = Post::when($request->search, function ($query) use ($request) {
            $search = $request->search;

            return $query->where('title', 'like', "%$search%")
                            ->orWhere('body', 'like', "%$search%");
        })->with('tags', 'category', 'user')
                    ->withCount('comments')
                    ->published()
                    ->paginate(5);

        $category_data = Category::all();
        $sidebar_settings = Setting::all();
        $popular_post = Post::query()->where("is_popular", 1)->take(5)->get();
        $recent_post = Post::latest()->paginate(5);
        $trending_post = Post::query()->where("is_trending", 1)->take(10)->get();
        $popular_category = Category::query()->where("is_popular", 1)->take(5)->withCount('posts')->get();
        $popular_tags = Tag::query()->where("is_popular", 1)->take(5)->get();
        $banners = Banner::latest()->paginate(1);
        return view('frontend.index', compact('posts','view_type','category_data','sidebar_settings','popular_post','recent_post','trending_post','popular_category','popular_tags','banners'));
    }

    public function post(Post $post)
    {
        $post = $post->load(['comments.user', 'tags', 'user', 'category']);
        $category_data = Category::paginate(4);
        $count_cat = Category::count();
        $skip = 4;
        $limit = $count_cat - $skip; // the limit
        $cat_data = Category::skip($skip)->take($limit)->get();
        $sidebar_settings = Setting::all();
        $popular_post = Post::query()->where("is_popular", 1)->take(5)->get();
        $recent_post = Post::latest()->paginate(5);
        $trending_post = Post::query()->where("is_trending", 1)->take(10)->get();
        $popular_category = Category::query()->where("is_popular", 1)->take(5)->withCount('posts')->get();
        $popular_tags = Tag::query()->where("is_popular", 1)->take(5)->get();
        $banners = Banner::latest()->paginate(1);
        $related_post = Post::query()->where("category_id", $post->category_id)->where("id",'!=', $post->id)->take(2)->get();
        return view('frontend.post', compact('post','category_data','cat_data','sidebar_settings','popular_post','recent_post','trending_post','popular_category','popular_tags','banners','related_post'));
    }

    public function catPostBySlug($slug)
    {
        $view_type = ($request->list_type) ?? 'list';
        $category_id = Category::where('slug',$slug)->pluck('id')->first();
        $posts = Post::where('category_id', $category_id)->with('tags', 'category', 'user')
        ->withCount('comments')
        ->published()
        ->simplePaginate(5);

        $category_data = Category::all();
        $sidebar_settings = Setting::all();
        $popular_post = Post::query()->where("is_popular", 1)->take(5)->get();
        $recent_post = Post::latest()->paginate(5);
        $trending_post = Post::query()->where("is_trending", 1)->take(10)->get();
        $popular_category = Category::query()->where("is_popular", 1)->take(5)->withCount('posts')->get();
        $popular_tags = Tag::query()->where("is_popular", 1)->take(5)->get();
        $banners = Banner::latest()->paginate(1);
        return view('frontend.index', compact('slug','posts','view_type','category_data','sidebar_settings','popular_post','recent_post','trending_post','popular_category','popular_tags','banners'));
    }
    
    public function tagPostBySlug($slug)
    {
        $view_type = ($request->list_type) ?? 'list';
        $tag_id = Tag::where('slug',$slug)->pluck('id')->first();
        $posts = Post::with('tags', 'category', 'user')
        ->withCount('comments')
        ->join('post_tag', 'post_tag.post_id', '=', 'posts.id')->where('post_tag.tag_id',$tag_id)
        ->published()
        ->paginate(5);

        $category_data = Category::all();
        $sidebar_settings = Setting::all();
        $popular_post = Post::query()->where("is_popular", 1)->take(5)->get();
        $recent_post = Post::latest()->paginate(5);
        $trending_post = Post::query()->where("is_trending", 1)->take(10)->get();
        $popular_category = Category::query()->where("is_popular", 1)->take(5)->withCount('posts')->get();
        $popular_tags = Tag::query()->where("is_popular", 1)->take(5)->get();
        $banners = Banner::latest()->paginate(1);
        return view('frontend.index', compact('slug','posts','view_type','view_type','category_data','sidebar_settings','popular_post','recent_post','trending_post','popular_category','popular_tags','banners'));
    }

    public function comment(Request $request, Post $post)
    {
        $this->validate($request, ['body' => 'required']);

        $post->comments()->create([
            'body' => $request->body,
        ]);
        flash()->overlay('Comment successfully created');

        return redirect("/posts/{$post->id}");
    }
}
